# yassm
Yet Another Simple Secret Manager

## What does it do?
Loads secrets held in AWS Secrets Manager into local environment variables, given a map of secret ID/key -> environment variable name.

## Installing
```shell
pip install yassm
```

## Using
```
yassm --help
```
